*  Suppress the Results Viewer;

ods noresults;

*  Directory for SAS code, data and output - remember trailing slash;

%let SAMPDIR=C:\HOW\DelGobbo\;

*  Library containing the sample data;

libname sample "&SAMPDIR" access=read;

*  Library to store styles and tagsets;

libname mylib "&SAMPDIR";

*  Set the ODS search path for styles and tagsets;

ods path mylib.tmplmst(update)
         sashelp.tmplmst(read);

*  Include recent version of the ExcelXP ODS tagset;

%include "&SAMPDIR.ExcelXP.sas";

*;
*  Create a user-defined style based on the "sansPrinter" 
*  style supplied by SAS.
*;

proc template;
  define style styles.XLsansPrinter;
    parent=styles.sansPrinter;

    style header from header /
      font_size = 10pt
      just      = center
      vjust     = bottom;

  end;
run; quit;

*;
*  Create formats to make drug codes
*  and Boolean values more user-friendly
*;

proc format;

  value rx 1 = 'Placebo'
           2 = '0.2 mg Estrogen'
           3 = '1.0 mg Estrogen'
           4 = '5.0 mg Estrogen';

  value boolean 0 = ' '
                1 = 'Yes';
run; quit;

ods listing close;
ods tagsets.ExcelXP path="&SAMPDIR" file='ProstateCancer.xml' style=XLsansPrinter;

ods tagsets.ExcelXP options(sheet_interval='bygroup'
                            sheet_label=' '
                            suppress_bylines='yes'
                            autofilter='2-7'
                            absolute_column_width='7.14,10.43,18.29,23.57,18.29,27.71,14.43,7.29,8'
                            width_fudge='0.58');

title;
footnote;

*  One worksheet created for each distinct BY value;

proc report data=sample.ProstateCancer nowindows split='*';
  by RX;
  column PatNo Age SZ Status HX EKG BM SBP DBP;

  define PatNo  / display style(Column)=[just=center];
  define Age    / display style(Column)=[just=center];
  define SZ     / display style(Column)=[just=center];
  define Status / display;
  define HX     / display format=boolean. style(Column)=[just=center];
  define EKG    / display;
  define BM     / display format=boolean. style(Column)=[just=center];
  define SBP    / display style(Column)=[just=center];
  define DBP    / display style(Column)=[just=center];

  compute PatNo;
    * Placeholder for row highlighting; 
    RowNum+1;
    if (mod(RowNum, 2) ne 0)
      then call define(_row_, 'style', 'style=[background=#99ccff]');
  endcomp;

  compute Status;
    * Placeholder for cell highlighting; 
    if (Status eq 'dead - heart or vascular')
      then call define('Status', 'style', 'style=[background=#ff6600]');
  endcomp;

  format RX rx.;

run; quit;

ods tagsets.ExcelXP close;
